==> aws-cdk.aws-kinesisfirehose-destinations-1.133.0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_kinesisfirehose_destinations_BackupMode(p) {
}
function _aws_cdk_aws_kinesisfirehose_destinations_S3BucketProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.compression))
        _aws_cdk_aws_kinesisfirehose_destinations_Compression(p.compression);
    if (!visitedObjects.has(p.s3Backup))
        _aws_cdk_aws_kinesisfirehose_destinations_DestinationS3BackupProps(p.s3Backup);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_kinesisfirehose_destinations_CommonDestinationS3Props(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.compression))
        _aws_cdk_aws_kinesisfirehose_destinations_Compression(p.compression);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_kinesisfirehose_destinations_CommonDestinationProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.s3Backup))
        _aws_cdk_aws_kinesisfirehose_destinations_DestinationS3BackupProps(p.s3Backup);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_kinesisfirehose_destinations_DestinationS3BackupProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.mode))
        _aws_cdk_aws_kinesisfirehose_destinations_BackupMode(p.mode);
    if (!visitedObjects.has(p.compression))
        _aws_cdk_aws_kinesisfirehose_destinations_Compression(p.compression);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_kinesisfirehose_destinations_S3Bucket(p) {
}
function _aws_cdk_aws_kinesisfirehose_destinations_Compression(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_kinesisfirehose_destinations_BackupMode, _aws_cdk_aws_kinesisfirehose_destinations_S3BucketProps, _aws_cdk_aws_kinesisfirehose_destinations_CommonDestinationS3Props, _aws_cdk_aws_kinesisfirehose_destinations_CommonDestinationProps, _aws_cdk_aws_kinesisfirehose_destinations_DestinationS3BackupProps, _aws_cdk_aws_kinesisfirehose_destinations_S3Bucket, _aws_cdk_aws_kinesisfirehose_destinations_Compression };
module.exports.DeprecationError = DeprecationError;

==> aws-cdk.aws-kinesisfirehose-destinations-1.150.0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_kinesisfirehose_destinations_BackupMode(p) {
}
function _aws_cdk_aws_kinesisfirehose_destinations_S3BucketProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.compression))
        _aws_cdk_aws_kinesisfirehose_destinations_Compression(p.compression);
    if (!visitedObjects.has(p.s3Backup))
        _aws_cdk_aws_kinesisfirehose_destinations_DestinationS3BackupProps(p.s3Backup);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_kinesisfirehose_destinations_CommonDestinationS3Props(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.compression))
        _aws_cdk_aws_kinesisfirehose_destinations_Compression(p.compression);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_kinesisfirehose_destinations_CommonDestinationProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.s3Backup))
        _aws_cdk_aws_kinesisfirehose_destinations_DestinationS3BackupProps(p.s3Backup);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_kinesisfirehose_destinations_S3Bucket(p) {
}
function _aws_cdk_aws_kinesisfirehose_destinations_DestinationS3BackupProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.mode))
        _aws_cdk_aws_kinesisfirehose_destinations_BackupMode(p.mode);
    if (!visitedObjects.has(p.compression))
        _aws_cdk_aws_kinesisfirehose_destinations_Compression(p.compression);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_kinesisfirehose_destinations_Compression(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_kinesisfirehose_destinations_BackupMode, _aws_cdk_aws_kinesisfirehose_destinations_S3BucketProps, _aws_cdk_aws_kinesisfirehose_destinations_CommonDestinationS3Props, _aws_cdk_aws_kinesisfirehose_destinations_CommonDestinationProps, _aws_cdk_aws_kinesisfirehose_destinations_S3Bucket, _aws_cdk_aws_kinesisfirehose_destinations_DestinationS3BackupProps, _aws_cdk_aws_kinesisfirehose_destinations_Compression };
module.exports.DeprecationError = DeprecationError;
